// *********************************************************
// Persistence Of Vision Ray Tracer Scene Description File
// File name  : cars_test.pov
// Version    : 3.6.1
// Description: simple demo for my cars kit
// Date       : Apr. 2005
// Author     : Jaime Vives Piqueres
// Requires   : Lightsys 4 (www.ignorancia.org/lightsys.php)
// *********************************************************

// *** REQUIRED STANDARD INCLUDES ***
#include "colors.inc"
#include "textures.inc"
#include "stones.inc"
#include "metals.inc"
#include "glass.inc"
#include "functions.inc"

	
// *** CONTROL CENTER ***
#declare use_blur    =7*0;  // # of samples (0=off)
#declare use_radiosity =1;   // 0=off, 1=load, 2=save
#declare rad_brightness=1.5; // radiosity brightness
// camera location and look_at declared here as the car paint needs them
#declare clo=<12,4,4>;
#declare cla=<2,0,-.5>;


// *** GLOBAL ***
global_settings{
 max_trace_level 6
 assumed_gamma 1.5
 #if (use_radiosity)
  radiosity{
   #include "i_outdoor_rad.inc"
  }
 #end
}
#default{texture{finish{ambient 0}}}


// *** CIE & LIGHTSYS ***
#include "CIE.inc"
#include "lightsys.inc"          
#include "espd_lightsys.inc"          
#include "rspd_jvp.inc"          
#declare Lightsys_Brightness=.9;


// *** SCENERY ***
plane{y,0
 pigment{Gray}
}


// *** SUN & SKY ***
// change white point to typical outdoor white balance
CIE_ColorSystemWhitepoint(CIE_ColSys,Daylight2Whitepoint(5500))
// skylight params:
#declare Current_Turbidity=3; // skylight turbidity (influences haze)
#declare Intensity_Mult   =1; // skylight intensity
#declare Max_Vertices  =2000; // skylight mesh resolution
#declare Sun_Size      =500; // aparent size of the sun
// sun settings 
#declare Az   =330;
#declare Al   = 48;
#declare North=z;
#include "i_sky.inc"


// *** THE CARS ***
// control data
#declare car_lights=0;
// predefined car textures
#declare rmin=.1;
#declare rmax=1;
#declare metallic_normal=1;
#include "i_car-textures.inc"
#include "i_car1.inc"
#declare car1=object{jvp_car_1(t_DarkGold_paint,0)}
#include "i_car2.inc"
#declare car2=object{jvp_car_2(t_DarkSilver_paint,0)}
#include "i_car3.inc"
#declare car3=object{jvp_car_3(t_BlueYellow_paint,0)}
#include "i_car4.inc"
#declare car4=object{jvp_car_4(t_BlueRed_paint,0)}
#include "i_car5.inc"
#declare car5=object{jvp_car_5(t_YellowRed_paint,0)}
object{car1 translate <5,0,0>}
object{car2 translate <2.5,0,-1.5>}
object{car3 translate <0,0,-3>}
object{car4 translate <-2.5,0,-1.5>}
object{car5 translate <-5,0,0>}


// **************
// *** camera ***
// **************
#declare cd=.005*z;
camera{
 location clo
 up .0024*y right .0042*x // 1:1.75
 direction cd
 look_at cla
 #if (use_blur)
 focal_point cla
 aperture .01
 blur_samples use_blur
 variance 0
 #end
}

